<template>
    <div class="box">
        <div style="display: flex">
            <el-form
                ref="searchForm"
                :model="searchForm"
                label-width="80px"
                class="searchTop"
            >
                <CascaderCompany
                    :companyIds.sync="searchForm.companyIds"
                    :companyId.sync="searchForm.companyId"
                    :roadSegmentId.sync="searchForm.roadSegmentId"
                    :placeholder="'请选择公司名称'"
                />

                <!-- <el-select
                    v-model="searchForm.roadSegmentId"
                    placeholder="请选择路段"
                    clearable
                >
                    <el-option
                        v-for="item in roadData"
                        :key="item.key"
                        :label="item.value"
                        :value="item.key"
                    >
                    </el-option>
                </el-select> -->
                <dict-select
                    dictCode="hdlx"
                    :hasDefaultOption="true"
                    clearable
                    v-model="searchForm.type"
                    placeholder="请选择涵洞类型"
                />
                <dict-select
                    dictCode="fx"
                    :hasDefaultOption="true"
                    clearable
                    v-model="searchForm.direction"
                    placeholder="请选择涵洞方向"
                />
                <el-date-picker
                    v-model="searchForm.finishDay"
                    type="date"
                    placeholder="请选择建成日期"
                    value-format="yyyy-MM-dd"
                >
                </el-date-picker>
                <el-button size="small" @click="findinfo()" type="primary"
                    >查询</el-button
                >
                <el-button size="small" @click="handleReset" type="plain">重置</el-button>
            </el-form>
        </div>
        <el-divider></el-divider>

        <ht-table
            @load="loadData"
            :data="data"
            :pageResult="pageResult"
            :selection="true"
            :show-custom-column="false"
            :show-export="false"
            ref="htTable"
            :default-sorter="[{direction: 'ASC', property: 'sn'}]"
        >
            <template>
                <ht-table-column
                    prop="number"
                    label="涵洞编号"
                    :show-overflow-tooltip="true"
                />
                <ht-table-column
                    prop="name"
                    label="涵洞名称"
                    :show-overflow-tooltip="true"
                />
                <ht-table-column
                    prop="companyName"
                    label="所属公司"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                />
                <!-- <ht-table-column
          prop="centPeg"
          label="中心桩号"
          width='120px'
          :show-overflow-tooltip="true"
          :sortable="true"
        /> -->
                <ht-table-column
                    prop="centPegAndRampPegK"
                    label="匝道桩号"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                />
                <ht-table-column
                    prop="officeName"
                    label="管养单位"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                />
                <ht-table-column
                    prop="direction"
                    label="方向"
                    :show-overflow-tooltip="true"
                    :filters="getDictData('fx')"
                >
                    <template v-slot="{row}">
                        {{ getDictName('fx', row.direction) }}
                    </template>
                </ht-table-column>
                <ht-table-column
                    prop="roadSegmentName"
                    label="所属路段"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                />
                <ht-table-column
                    prop="type"
                    label="涵洞类型"
                    :show-overflow-tooltip="true"
                    :filters="getDictData('hdlx')"
                >
                    <template v-slot="{row}">
                        <el-tag>{{ getDictName('hdlx', row.type) }}</el-tag>
                        <!-- <el-tag>{{row.type === '1' ? '盖板涵' : row.type === '2' ? '管涵' : row.type === '3' ? '箱涵' : row.type === '4' ? '供涵' : '倒虹吸'}}</el-tag> -->
                    </template>
                </ht-table-column>
                <ht-table-column
                    prop="height"
                    label="涵洞高度(m)"
                    :show-overflow-tooltip="true"
                />
                <ht-table-column
                    prop="length"
                    label="涵洞长度(m)"
                    :show-overflow-tooltip="true"
                />
                <ht-table-column
                    prop="finishDay"
                    label="完成日期"
                    :show-overflow-tooltip="true"
                />
                <ht-table-column label="操作" width="150">
                    <template v-slot="{row}">
                        <el-button type="pimary" @click="handleCommand(row)">
                            档案查看
                        </el-button>
                        <!-- <el-dropdown
              size="mini"
              split-button
              @command="handleCommand"
              @click="handleCommand({row, command: 'inspect'})"
            >
              <span><i class="el-icon-view"></i> 检查记录</span>
              <el-dropdown-menu slot="dropdown">
                <el-dropdown-item
                  icon="el-icon-tickets"
                  :command="{row: row, command: 'disease'}"
                  >病害记录</el-dropdown-item
                >
                <el-dropdown-item
                  icon="el-icon-tickets"
                  :command="{row: row, command: 'curing'}"
                  >养护记录</el-dropdown-item
                >
              </el-dropdown-menu>
            </el-dropdown> -->
                    </template>
                </ht-table-column>
            </template>
        </ht-table>
        <!-- 添加弹出框 -->
    </div>
</template>
<script>
import req from '@/request.js'
import basicData from '@/api/basicData.js'
import RoadInfoDialog from '@/components/dialog/RoadInfoDialog.vue'
import eipOrgSelector from '@/components/eipControl/selector/EipOrgSelector.vue'
import sctionInfoSelector from '@/components/selector/sctionInfoSelector.vue'
import companyInfoSelector from '@/components/selector/companyInfoSelector.vue'
import CascaderCompany from '@/components/selector/CascaderCompany.vue'
export default {
    name: 'CulvertManagement',
    components: {
        // RoadInfoDialog,
        // eipOrgSelector,
        // sctionInfoSelector,
        // companyInfoSelector,
        CascaderCompany,
    },
    data() {
        return {
            data: [],
            searchForm: {},
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            dialogVisible: false,
            //判断是否是添加还是修改
            type: '',
            form: {
                roadSegmentName: '', //所属路段
                type: '1', //涵洞类型
                direction: '1', //方向
                topMaterial: '1', //上层材料
                bodyMaterial: '1', //身体材料
                entranceMaterial: '1', //入口材料
                exitMaterial: '1', //出口材料
                entranceForm: '1', //入口形式
                exitForm: '1', //exitForm
                companyName: '',
                uses: '1', //用途
            },
            permission: 'b',
            drivewayTypeArray: [
                {text: '盖板涵', value: '1'},
                {text: '管涵', value: '2'},
                {text: '箱涵', value: '3'},
                {text: '供涵', value: '4'},
                {text: '倒虹吸', value: '5'},
            ],
            roadData: [], //路段下拉信息
        }
    },
    created() {
        //获取路段下拉信息
        this.roadData = this.getRoadData()
    },
    computed: {
        // deleteUrl: function() {
        //   return (
        //     window.context.yhxt +
        //     '/bizCulvertInformation/bizCulvertInformationmanager/v1/updateCulvertInformation'
        //   )
        // }
    },
    methods: {
        getRoadData() {
            let arr = []
            basicData.getRoadManagement().then((res) => {
                // console.log(res, 'ffff')
                res.rows.forEach((item) => {
                    arr.push({
                        value: item.name,
                        key: item.id,
                    })
                })
            })
            return arr
        },
        //字典触发回调事件
        handleDict(val, obj, str) {
            // console.log(val, obj, str)
            // this.form.direction = obj.name
            if (str === 'fx') {
                this.form.direction = obj.value
            } else if (str === 'hdlx') {
                this.form.typeValue = obj.name
            } else if (str === 'sccl') {
                this.form.topMaterialValue = obj.name
            } else if (str === 'stcl') {
                this.form.bodyMaterialValue = obj.name
            } else if (str === 'rkcl') {
                this.form.entranceMaterialValue = obj.name
            } else if (str === 'rkxs') {
                this.form.entranceFormlValue = obj.name
            } else if (str === 'yt') {
                this.form.usesValue = obj.name
            } else if (str === 'ckcl') {
                this.form.exitMaterialValue = obj.name
            } else if (str === 'ckxs') {
                this.form.exitFormlValue = obj.name
            }
        },
        //所属路段获取焦点触发事件
        handleFocusRoad() {
            this.$refs.road.open()
        },
        // //路段类型下拉事件
        // handleSelectType(value) {
        //   if (value === '1') {
        //     this.form.typeValue = '检查路段'
        //   } else {
        //     this.form.typeValue = '费用路段'
        //   }
        // },
        //所属路线打开弹框
        openRoad() {
            this.$refs.road.open()
        },
        //选取路线回填数据
        handleSelectRoad(data) {
            // console.log(data.name, '路线信息')
            this.form.roadSegmentName = data.name
            this.form.roadSegmentId = data.id
            this.$refs.roadSegmentName.focus()
            this.$refs.roadSegmentName.blur()
            // console.log(this.form.routeName)
        },
        afterDelete() {
            // this.$refs.htTable.load()
        },
        //新增
        handleAdd() {
            // this.dialogVisible = true
            // this.type = 'add'
        },
        //修改
        handleEdit(data) {
            let form = {
                roadSegmentName: '', //所属路段
                type: '1', //涵洞类型
                direction: '1', //方向
                topMaterial: '1', //上层材料
                bodyMaterial: '1', //身体材料
                entranceMaterial: '1', //入口材料
                exitMaterial: '1', //出口材料
                entranceForm: '1', //入口形式
                exitForm: '1', //exitForm
                companyName: '',
                uses: '1', //用途
            }
            this.type = 'edit'
            this.dialogVisible = true
            this.form = {...form, ...data}
        },
        handleClose(done) {
            //清空表单
            // this.form = {companyName: '', companyId: ''}
            ;(this.form = {
                roadSegmentName: '', //所属路段
                type: '1', //涵洞类型
                direction: '1', //方向
                topMaterial: '1', //上层材料
                bodyMaterial: '1', //身体材料
                entranceMaterial: '1', //入口材料
                exitMaterial: '1', //出口材料
                entranceForm: '1', //入口形式
                exitForm: '1', //exitForm
                companyName: '',
                uses: '1', //用途
            }),
                done()
        },
        //取消弹窗
        handleCancel() {
            //清空表单
            // this.form = {companyName: '', companyId: ''}
            ;(this.form = {
                roadSegmentName: '', //所属路段
                type: '1', //涵洞类型
                direction: '1', //方向
                topMaterial: '1', //上层材料
                bodyMaterial: '1', //身体材料
                entranceMaterial: '1', //入口材料
                exitMaterial: '1', //出口材料
                entranceForm: '1', //入口形式
                exitForm: '1', //exitForm
                companyName: '',
                uses: '1', //用途
            }),
                (this.dialogVisible = false)
        },
        //提交保存或者修改
        handleSubmit() {
            //验证表单是否填写完
            this.$refs.form.validate((bool) => {
                if (bool) {
                    this.dialogVisible = false
                    //请求保存提交
                    basicData.addCulvertManagement(this.form).then((res) => {
                        this.$message.success(res.message)
                        // this.form = {companyName: '', companyId: ''}
                        this.form = {
                            roadSegmentName: '', //所属路段
                            type: '1', //涵洞类型
                            direction: '1', //方向
                            topMaterial: '1', //上层材料
                            bodyMaterial: '1', //身体材料
                            entranceMaterial: '1', //入口材料
                            exitMaterial: '1', //出口材料
                            entranceForm: '1', //入口形式
                            exitForm: '1', //exitForm
                            companyName: '',
                            uses: '1', //用途
                        }
                        this.loadData() //重新获取数据
                    })
                }
            })
        },
        uniqueFunc(arr, uniId) {
            const res = new Map()
            return arr.filter((item) => !res.has(item[uniId]) && res.set(item[uniId], 1))
        },
        handleReset() {
            this.searchForm = {
                ...this.searchForm,
                companyId: ['1419863231459102720'],
                companyIds: '',
                roadSegmentId: '',
                direction: '',
                finishDay: '',
                type: '',
            }
            this.findinfo()
        },
        findinfo() {
            typeof this.$refs.filterTable !== 'undefined' &&
                this.$refs.filterTable.clearFilter()
            let query = []
            let params = {routeId: this.searchForm.routeId}
            let search = {
                company_id_: this.searchForm.companyIds,
                road_segment_id_: this.searchForm.roadSegmentId,
                finish_day_: this.searchForm.finishDay,
                type: this.searchForm.type,
                direction: this.searchForm.direction,
            }
            for (let i in search) {
                if (search[i]) {
                    if (i == 'company_id_') {
                        query.push({
                            group: 'companyIds',
                            operation: 'IN',
                            parentGroup: '',
                            property: 'COMPANY_ID_',
                            relation: 'AND',
                            value: search[i],
                        })
                    } else if (i == 'road_segment_id_') {
                        query.push({
                            group: 'main',
                            operation: 'EQUAL',
                            parentGroup: '',
                            property: 'road_segment_id_',
                            relation: 'AND',
                            value: search[i],
                        })
                    } else {
                        query.push({
                            group: 'advance',
                            operation: 'LIKE',
                            property: i,
                            relation: 'AND',
                            value: search[i],
                        })
                    }
                }
            }
            query = this.uniqueFunc(query, 'property')
            let data = {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true,
                },
                querys: query,
                params: params,
            }
            this.topQuery = query
            basicData.getCulvertManagement(data).then((res) => {
                console.log(res, '11')

                this.data = res.rows
                this.pageResult = {
                    page: res.page,
                    pageSize: res.pageSize,
                    total: res.total,
                }
            })
        },
        loadData(param, cb) {
            // let r = JSON.stringify(param.pageBean)
            // let l = JSON.stringify(this.pageResult)
            // console.log(r, l)
            // if (r == l) {
            //   console.log('一样')
            //   param
            // } else {
            //   console.log('不一样')
            //   let query = []
            //   let params = {routeId: this.searchForm.routeId}
            //   let search = {
            //     company_id_: this.searchForm.companyId,
            //     road_segment_name_: this.searchForm.roadSegmentName,
            //     finish_day_: this.searchForm.finishDay,
            //     type_: this.searchForm.type
            //   }
            //   for (let i in search) {
            //     if (search[i]) {
            //       query.push({
            //         group: 'advance',
            //         operation: 'LIKE',
            //         property: i,
            //         relation: 'AND',
            //         value: search[i]
            //       })
            //     }
            //   }
            //   param.querys = query
            //   param.params = params
            // }
            if (typeof this.topQuery !== 'undefined' && this.topQuery.length !== 0) {
                param.querys = typeof param.querys !== 'undefined' ? param.querys : []
                this.topQuery.forEach((item) => {
                    param.querys.push(item)
                })
                param.querys = this.uniqueFunc(param.querys, 'property')
            }
            this.exportQuery = param
            basicData
                .getCulvertManagement(param)
                .then((response) => {
                    console.log(response)
                    this.data = response.rows
                    this.pageResult = {
                        page: response.page,
                        pageSize: response.pageSize,
                        total: response.total,
                    }
                })
                .finally(() => {
                    if (cb) {
                        cb()
                    }
                })
        },
        //路段信息赋值
        changed(obj) {
            this.form.roadSegmentName = obj.name
            this.form.roadSegmentId = obj.id
        },
        //默认赋值为第一条数据的值
        value(obj) {
            this.form.roadSegmentName = obj.name
            this.form.roadSegmentId = obj.id
        },
        //公司赋值
        handleChanged(obj) {
            // console.log(obj.valueInfo.join(','))
            this.form.companyIds = JSON.stringify(obj.valueInfo)
            this.form.companyName = obj.name
            this.form.companyId = obj.id
        },
        companyValue(obj) {
            // console.log(obj)
            this.form.companyName = obj.name
            this.form.companyId = obj.id
            this.form.companyIds = JSON.stringify(obj.id.split(' ')) //必须是空格
        },
        //操作事件
        handleCommand(params) {
            let params_ = {
                row: params,
                sign: 'culvert',
            }
            this.$router.push({
                name: 'culvertIndex',
                params: params_,
            })
            // 检查记录
            //   if (params.command == 'inspect') {
            //     this.$router.push({
            //       name: 'culvertIndex',
            //       params
            //     })
            //     //病害记录
            //   } else if (params.command == 'disease') {
            //     this.$router.push({
            //       name: 'disease',
            //       params
            //     })
            //     //养护记录
            //   } else if (params.command == 'curing') {
            //     params.sign = 'culvert'
            //     this.$router.push({
            //       name: 'workOrderInfo',
            //       params
            //     })
            //   }
        },
    },
}
</script>
<style lang="scss" scoped>
.box {
    // padding: 10px;
}
// /deep/ .el-main {
//   .el-table {
//     height: 745px !important;
//   }
// }
/deep/ .el-dialog__header {
    border-right: 1px solid #103c5d;
}
/deep/.el-dialog::-webkit-scrollbar {
    display: none;
}
//弹出层居中
/deep/ .el-dialog {
    display: flex;
    flex-direction: column;
    margin: 0 !important;
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
}
/deep/ .el-dialog .el-dialog__body {
    flex: 1;
    overflow: auto;
}
/deep/.el-divider--horizontal {
    height: 10px;
    margin: 0 !important;
    position: absolute;
    left: 0;
}
/deep/.ht-table-panel {
    // padding-top: 20px;
    // height: calc(100% - 7%);
    overflow: hidden;
    // background: #fff;
    // display: flex;
    // flex-direction: column;
    // justify-content: space-between;
}
/deep/.ht-quick__search {
    // margin-bottom: 10px;
}
/deep/.ht-table {
    // height: calc(100% - 4vw) !important;
    // max-height: calc(100% - 4vw) !important;
}
/deep/.pagination-panel {
    // padding: 10px 0 0 0;
}
.searchTop > div {
    max-width: 200px;
}
</style>
